YARP 2.1.9 (2008-17-03)                                                {#v2_1_9}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.1.8...v2.1.9`):

```
   225	Paul Fitzpatrick <paulfitz@alum.mit.edu>
    41	Giacomo Spigler <spiglerg@gmail.com>
    15	Lorenzo Natale <lorenzo.natale@iit.it>
     6	YARP Developers <yarp0-devel@lists.sourceforge.net>
     5	Alexandre Bernardino <alex@isr.ist.utl.pt>
     4	Giorgio Metta <giorgio.metta@iit.it>
     2	Alessandro Scalzo <alessandro.scalzo@iit.it>
```
